(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     39786,       1076]
NotebookOptionsPosition[     35647,        991]
NotebookOutlinePosition[     36140,       1010]
CellTagsIndexPosition[     36097,       1007]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Appendix 1 - Model analysis", "Section",
 CellChangeTimes->{{3.535454298217599*^9, 3.535454300817389*^9}, {
  3.535534021216524*^9, 
  3.535534037341701*^9}},ExpressionUUID->"da3e0881-e02c-430b-9752-\
d189594494ef"],

Cell[CellGroupData[{

Cell["Model setup", "Subsection",
 CellChangeTimes->{{3.535454304249093*^9, 
  3.5354543070919867`*^9}},ExpressionUUID->"f4c5663f-07f4-409c-bcfb-\
5319dacb70d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"C", "-", 
    RowBox[{"lim", " ", "and", " ", "N"}], "-", 
    RowBox[{"lim", " ", "plant", " ", "growth"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gpclim", ":=", 
     RowBox[{"fcp", "-", 
      RowBox[{"x", "/", "p"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gpnlim", ":=", 
     RowBox[{"ynp", "*", 
      RowBox[{"(", 
       RowBox[{"fnp", "+", 
        RowBox[{"x", "/", 
         RowBox[{"(", 
          RowBox[{"p", "*", "t"}], ")"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"C", "-", 
      RowBox[{"lim", " ", "and", " ", "N"}], "-", 
      RowBox[{
      "lim", " ", "rhizobir", " ", "growth", " ", "without", " ", 
       "respiration"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"grclim", ":=", 
      RowBox[{"fcr", "+", 
       RowBox[{"x", "/", "r"}]}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"grnlim", ":=", 
      RowBox[{"ynr", "*", 
       RowBox[{"(", 
        RowBox[{"fnr", "-", 
         RowBox[{"x", "/", 
          RowBox[{"(", 
           RowBox[{"r", "*", "t"}], ")"}]}]}], ")"}]}]}], ";"}], " ", 
    "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"C", "-", 
     RowBox[{"lim", " ", "and", " ", "N"}], "-", 
     RowBox[{
     "lim", " ", "rhizobia", " ", "growth", " ", "with", " ", 
      "respiration"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"grclim", ":=", 
     RowBox[{"fcr", "+", 
      RowBox[{"x", "/", "r"}], "-", 
      RowBox[{
       RowBox[{"257", "/", "100"}], "*", "fnr"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"grnlim", ":=", 
     RowBox[{"ynr", "*", 
      RowBox[{"(", 
       RowBox[{"fnr", "-", 
        RowBox[{"x", "/", 
         RowBox[{"(", 
          RowBox[{"r", "*", "t"}], ")"}]}]}], ")"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"organismal", " ", "growth"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gp", ":=", 
     RowBox[{"Min", "[", 
      RowBox[{"gpclim", ",", "gpnlim"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr", ":=", 
     RowBox[{"Min", "[", 
      RowBox[{"grclim", ",", "grnlim"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.4731642674684563`*^9, 3.473164307917968*^9}, {
   3.473518297645383*^9, 3.4735183021986923`*^9}, {3.4740348881263733`*^9, 
   3.4740348915630836`*^9}, 3.5353467038491497`*^9, {3.5353469575444927`*^9, 
   3.535346998156871*^9}, {3.535456365057827*^9, 3.535456395314704*^9}, {
   3.535456767079011*^9, 3.535456783487348*^9}, 3.712065099045765*^9, {
   3.72623276926409*^9, 3.72623289108947*^9}, 3.7262362764611053`*^9, {
   3.72623773229113*^9, 
   3.726237786102995*^9}},ExpressionUUID->"f5fe3749-a289-4b50-8065-\
cae120b360d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determining how much C is traded", "Subsection",
 CellChangeTimes->{{3.4735092888156233`*^9, 3.473509290421665*^9}, {
   3.535454224405839*^9, 3.535454226835471*^9}, 
   3.726232943795924*^9},ExpressionUUID->"0e0a2b7a-e589-4239-b9bd-\
5b5d129bc701"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"plant", " ", "surplus", " ", "carbon"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"scp", ":=", 
     RowBox[{"fcp", "-", 
      RowBox[{"x", "/", "p"}], "-", 
      RowBox[{"ynp", "*", 
       RowBox[{"(", 
        RowBox[{"fnp", "+", 
         RowBox[{"x", "/", 
          RowBox[{"(", 
           RowBox[{"p", "*", "t"}], ")"}]}]}], ")"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "rhizobia", " ", "surplus", " ", "nitrogen", " ", "without", " ", 
      "respiration"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"snr", ":=", 
      RowBox[{"fnr", "-", 
       RowBox[{"x", "/", 
        RowBox[{"(", 
         RowBox[{"r", "*", "t"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"1", "/", "ynr"}], "*", 
        RowBox[{"(", 
         RowBox[{"fcr", "+", 
          RowBox[{"x", "/", "r"}]}], ")"}]}]}]}], ";"}], " ", 
    "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "rhizobia", " ", "surplus", " ", "nitrogen", " ", "with", " ", 
     "respiration"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"snr", ":=", 
     RowBox[{"fnr", "-", 
      RowBox[{"x", "/", 
       RowBox[{"(", 
        RowBox[{"r", "*", "t"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"1", "/", "ynr"}], "*", 
       RowBox[{"(", 
        RowBox[{"fcr", "+", 
         RowBox[{"x", "/", "r"}], "-", 
         RowBox[{
          RowBox[{"257", "/", "100"}], "*", "fnr"}]}], ")"}]}]}]}], ";"}], 
   " "}]}]], "Input",
 CellChangeTimes->{{3.471911136710401*^9, 3.471911212023325*^9}, {
   3.473081876497101*^9, 3.47308188311189*^9}, {3.4735073676095943`*^9, 
   3.4735073815681543`*^9}, {3.4735074136169147`*^9, 3.473507416470792*^9}, {
   3.535347721997479*^9, 3.53534774713194*^9}, {3.535456753390564*^9, 
   3.5354567607241707`*^9}, {3.535456791910153*^9, 3.535456801244155*^9}, {
   3.5354604097624197`*^9, 3.535460411966568*^9}, 3.712065107510982*^9, {
   3.726232952668558*^9, 3.726232991655921*^9}, {3.726233435554126*^9, 
   3.7262334422267017`*^9}, 3.726236283437594*^9, {3.726237791722061*^9, 
   3.726237820486001*^9}},ExpressionUUID->"41c4a4cd-3237-4e2e-8ec8-\
433317143cd7"],

Cell[CellGroupData[{

Cell["Plant-limited trade", "Subsubsection",
 CellChangeTimes->{{3.47308157132934*^9, 3.473081575351103*^9}, 
   3.529322839559888*^9, {3.7262334721017017`*^9, 
   3.7262334743634453`*^9}},ExpressionUUID->"d32c7c3e-4511-4e12-afaf-\
c0839907b820"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "carbon", " ", "traded", " ", "when", " ", "the", " ", "plant", " ", 
    "limits", " ", "trade"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"xplim", "=", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"0", "\[Equal]", "scp"}], ",", "x"}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "rhizobia", " ", "surplus", " ", "nitrogen", " ", "when", " ", "the", " ",
      "plant", " ", "limits", " ", "trade"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"snr", "/.", "xplim"}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.471911912529415*^9, 3.471911928102169*^9}, {
   3.473162608644631*^9, 3.473162609326153*^9}, {3.4735074700065517`*^9, 
   3.4735074732548103`*^9}, 3.52932283956024*^9, {3.5353494200958767`*^9, 
   3.53534945298026*^9}, {3.535454800717849*^9, 3.535454803276084*^9}, {
   3.535460413293565*^9, 3.535460414893931*^9}, {3.726233500662264*^9, 
   3.7262335064177313`*^9}, {3.726235886826612*^9, 3.726235905173402*^9}, {
   3.7262387969616327`*^9, 
   3.7262387976370897`*^9}},ExpressionUUID->"6b289a2b-42fe-4cb9-9c91-\
9ad798f3d6cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rhizobia-limited trade", "Subsubsection",
 CellChangeTimes->{{3.473081581945291*^9, 3.473081584438936*^9}, {
  3.527745319217065*^9, 3.5277453198236217`*^9}, {3.530515225744296*^9, 
  3.5305152262552147`*^9}, {3.726233597717025*^9, 
  3.726233602063373*^9}},ExpressionUUID->"102f513b-df39-4e7c-bea5-\
60658c909ffd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "carbon", " ", "traded", " ", "when", " ", "rhizobia", " ", "limit", " ", 
    "trade"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"xrlim", "=", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"0", "\[Equal]", "snr"}], ",", "x"}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "plant", " ", "surplus", " ", "carbon", " ", "when", " ", "rhizobia", " ",
      "limit", " ", "trade"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"scp", "/.", "xrlim"}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.4719107261383333`*^9, 3.471910754291564*^9}, {
   3.471911129356719*^9, 3.4719111302970543`*^9}, {3.471911198650942*^9, 
   3.4719112008707943`*^9}, {3.471911351531146*^9, 3.4719113515923033`*^9}, {
   3.4731626313477163`*^9, 3.473162631999324*^9}, {3.473508707237965*^9, 
   3.473508711061576*^9}, 3.473508753293088*^9, {3.53535222959227*^9, 
   3.535352240774251*^9}, 3.5354604309975863`*^9, {3.726233618457052*^9, 
   3.7262336190403843`*^9}, 3.7262358634248743`*^9, {3.726237844180173*^9, 
   3.726237848126831*^9}, {3.726238810819968*^9, 
   3.726238811061721*^9}},ExpressionUUID->"3746d68d-723e-4af4-a01f-\
80f165ac91f9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determining root-to-shoot allocation", "Subsection",
 CellChangeTimes->{{3.5353566752842283`*^9, 3.5353566777631598`*^9}, {
   3.5354557544922533`*^9, 3.5354557562759953`*^9}, 
   3.726233837288014*^9},ExpressionUUID->"72186bf5-3410-44d5-bbae-\
87990a869cff"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"assumptions", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ynp", ">", "0"}], ",", 
      RowBox[{"ynr", ">", "0"}], ",", 
      RowBox[{"t", ">", "0"}], ",", 
      RowBox[{"fnp\[Prime]", ">", "0"}], ",", 
      RowBox[{"fcp\[Prime]", ">", "0"}], ",", 
      RowBox[{"fnr\[Prime]", ">", "0"}], ",", 
      RowBox[{"fcr\[Prime]", ">", "0"}], ",", 
      RowBox[{
       RowBox[{"fcr\[Prime]", "/", "fnr\[Prime]"}], "<", "t", "<", 
       RowBox[{"fcp\[Prime]", "/", "fnp\[Prime]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"set", " ", "up", " ", "linear", " ", "trade"}], "-", 
    RowBox[{
    "off", " ", "for", " ", "plant", " ", "organ", " ", "investment"}]}], " ",
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fcp", ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "anp"}], ")"}], "*", "fcp\[Prime]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fnp", ":=", 
    RowBox[{"anp", "*", "fnp\[Prime]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"set", " ", "up", " ", "linear", " ", "trade"}], "-", 
     RowBox[{
     "off", " ", "for", " ", "rhizobia", " ", "investment", " ", "without", 
      " ", "respiration"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fnr", ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "acr"}], ")"}], "*", "fnr\[Prime]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"fcr", ":=", 
     RowBox[{"acr", "*", "fcr\[Prime]"}]}], ";"}], "\[IndentingNewLine]", 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"set", " ", "up", " ", "linear", " ", "trade"}], "-", 
    RowBox[{
    "off", " ", "for", " ", "rhizobia", " ", "investment", " ", "with", " ", 
     "respiration"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fnr", ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "acr"}], ")"}], "*", 
    RowBox[{"157", "/", "257"}], "*", "fnr\[Prime]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fcr", ":=", 
    RowBox[{"acr", "*", "fcr\[Prime]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "optimal", " ", "plant", " ", "allocation", " ", "without", " ", "trade"}],
    " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"anpnox", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"fcp", "\[Equal]", 
        RowBox[{"ynp", "*", "fnp"}]}], ",", "anp"}], "]"}], 
     "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "optimal", " ", "rhizboba", " ", "allocation", " ", "without", " ", 
    "trade"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"acrnox", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"fcr", "\[Equal]", 
        RowBox[{
         RowBox[{"ynr", "*", "fnr"}], "+", 
         RowBox[{
          RowBox[{"257", "/", "100"}], "*", "fnr"}]}]}], ",", "acr"}], "]"}], 
     "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"plant", " ", "growth", " ", "without", " ", "trade"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gpnox", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"gp", "/.", "anpnox"}], "/.", 
      RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"rhizobia", " ", "growth", " ", "without", " ", "trade"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"grnox", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"gr", "/.", "acrnox"}], "/.", 
      RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"conditions", " ", "for", " ", "colimited", " ", "trade", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"solved", " ", "for", " ", "acr"}], " ", "&"}], " ", "anp"}], 
     ")"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"colim", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{"x", "/.", "xplim"}], "]"}], "\[Equal]", 
        RowBox[{"Evaluate", "[", 
         RowBox[{"x", "/.", "xrlim"}], "]"}]}], ",", "acr"}], "]"}], "]"}], 
    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"colim\[Prime]", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{"x", "/.", "xplim"}], "]"}], "\[Equal]", 
        RowBox[{"Evaluate", "[", 
         RowBox[{"x", "/.", "xrlim"}], "]"}]}], ",", "anp"}], "]"}], "]"}], 
    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5354588380310993`*^9, 3.535458843361665*^9}, {
  3.7262338509725037`*^9, 3.726233863581781*^9}, {3.72623786480083*^9, 
  3.726237879897057*^9}, {3.726238825691291*^9, 
  3.7262388814551697`*^9}},ExpressionUUID->"a7104deb-09b8-4b27-9d9c-\
77a33722e7a1"],

Cell[CellGroupData[{

Cell["Predictions when trade is ultimately plant limited ", "Subsubsection",
 CellChangeTimes->{{3.535459186213221*^9, 3.5354591917888937`*^9}, {
  3.726235568188258*^9, 3.726235573134858*^9}, {3.726235748781681*^9, 
  3.726235753737111*^9}},ExpressionUUID->"38b300d4-9182-4d9c-9dad-\
0dc40b822f5d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "rhizobia", " ", "allocation", " ", "when", " ", "trade", " ", "is", " ", 
    "ultimately", " ", "plant", " ", "limited"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"acr", "/.", "colim"}], "/.", "xplim"}], "/.", 
    RowBox[{"anp", "\[Rule]", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473512763605008*^9, 3.4735127986679373`*^9}, {
   3.535458923572959*^9, 3.535458944308942*^9}, 3.535460463116734*^9, {
   3.726235592791074*^9, 3.726235605339981*^9}, {3.726235679546628*^9, 
   3.726235683782743*^9}, 3.726235822695817*^9, {3.7262379907178*^9, 
   3.7262379908815947`*^9}, 
   3.726238903495125*^9},ExpressionUUID->"7783c95d-8772-4879-9c0a-\
102e9169f339"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "25700"}], " ", "fcp\[Prime]", " ", "p", " ", 
    RowBox[{"(", 
     RowBox[{"t", "+", "ynr"}], ")"}]}], "+", 
   RowBox[{"157", " ", "fnr\[Prime]", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{"t", "+", "ynp"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"257", "+", 
      RowBox[{"100", " ", "ynr"}]}], ")"}]}]}], 
  RowBox[{"r", " ", 
   RowBox[{"(", 
    RowBox[{"t", "+", "ynp"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"25700", " ", "fcr\[Prime]"}], "+", 
     RowBox[{"157", " ", "fnr\[Prime]", " ", 
      RowBox[{"(", 
       RowBox[{"257", "+", 
        RowBox[{"100", " ", "ynr"}]}], ")"}]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.726238984841631*^9},ExpressionUUID->"efd25634-edcd-4382-9be8-\
eb68ce70a02e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "plant", " ", "growth", " ", "when", " ", "trade", " ", "is", " ", 
    "ultimately", " ", "plant", " ", "limited"}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"gPplim", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"gp", "/.", "colim"}], "/.", "xplim"}], "/.", 
     RowBox[{"anp", "\[Rule]", "0"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.473513007176017*^9, 3.473513011563649*^9}, {
   3.473513205732048*^9, 3.473513232292549*^9}, {3.4735155673414927`*^9, 
   3.4735155676372423`*^9}, {3.4736831605759993`*^9, 
   3.4736831615437307`*^9}, {3.473684783541585*^9, 3.473684785659346*^9}, {
   3.535459008687912*^9, 3.535459037848691*^9}, {3.53545907674692*^9, 
   3.535459076825944*^9}, 3.5354604649655437`*^9, {3.726235617458296*^9, 
   3.7262356263665648`*^9}, {3.7262356881675777`*^9, 3.726235689452218*^9}, 
   3.726235815787182*^9, 
   3.726238907086104*^9},ExpressionUUID->"8d439f03-7e9f-4114-8f12-\
d65b00e0966a"],

Cell[BoxData[
 FractionBox[
  RowBox[{"fcp\[Prime]", " ", "ynp"}], 
  RowBox[{"t", "+", "ynp"}]]], "Output",
 CellChangeTimes->{
  3.726238985380476*^9},ExpressionUUID->"b09120fa-a506-4df3-a464-\
e9a997e103ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "rhizobia", " ", "growth", " ", "when", " ", "trade", " ", "is", " ", 
    "ultimately", " ", "plant", " ", "limited"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"gRplim", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"gr", "/.", "colim"}], "/.", "xplim"}], "/.", 
     RowBox[{"anp", "\[Rule]", "0"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.473513251082349*^9, 3.4735132579716387`*^9}, {
   3.473515571599132*^9, 3.47351557407054*^9}, {3.4736831633114643`*^9, 
   3.4736831642871113`*^9}, {3.473684827957353*^9, 3.4736848303312263`*^9}, {
   3.535459042456431*^9, 3.535459078914061*^9}, 3.535460466484559*^9, {
   3.7262356388362007`*^9, 3.7262356926118393`*^9}, 3.726235774755802*^9, 
   3.726235814265456*^9, {3.7262379981398*^9, 3.726238001728868*^9}, {
   3.726238358483232*^9, 3.7262383593225327`*^9}, 
   3.7262389080984993`*^9},ExpressionUUID->"dc2be358-cd41-4460-88f7-\
d8846c294c5f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"fcp\[Prime]", " ", "p", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "25700"}], " ", "fcr\[Prime]"}], "+", 
        RowBox[{"157", " ", "fnr\[Prime]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "257"}], "+", 
           RowBox[{"100", " ", "t"}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"15700", " ", "fcr\[Prime]", " ", "fnr\[Prime]", " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{"t", "+", "ynp"}], ")"}]}]}], ")"}], " ", "ynr"}], 
  RowBox[{"r", " ", 
   RowBox[{"(", 
    RowBox[{"t", "+", "ynp"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"25700", " ", "fcr\[Prime]"}], "+", 
     RowBox[{"157", " ", "fnr\[Prime]", " ", 
      RowBox[{"(", 
       RowBox[{"257", "+", 
        RowBox[{"100", " ", "ynr"}]}], ")"}]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.726238986113639*^9},ExpressionUUID->"46499038-827a-4040-855c-\
26aab38c79e1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Predictions when trade is ultimately rhizobia limited ", "Subsubsection",
 CellChangeTimes->{{3.535459197172474*^9, 3.5354592000365334`*^9}, {
  3.5356484034884567`*^9, 3.535648404407057*^9}, {3.7262357463972588`*^9, 
  3.7262357639915657`*^9}},ExpressionUUID->"83890d21-f09f-4b17-9233-\
181a21c6aea2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "plant", " ", "allocation", " ", "when", " ", "trade", " ", "is", " ", 
    "ultimately", " ", "rhizobia", " ", "limited"}], " ", "*)"}], "\n", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"anp", "/.", "colim\[Prime]"}], "/.", "xrlim"}], "/.", 
    RowBox[{"acr", "\[Rule]", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473513384546631*^9, 3.473513390023011*^9}, {
   3.473513577322178*^9, 3.4735135835114594`*^9}, {3.473513662836285*^9, 
   3.473513682396234*^9}, {3.473515576670755*^9, 3.4735155767427397`*^9}, {
   3.535459226110722*^9, 3.5354592277986107`*^9}, 3.535459262461355*^9, 
   3.5354604710130663`*^9, {3.726235609151269*^9, 3.726235609734797*^9}, {
   3.726235695843128*^9, 3.7262357015337048`*^9}, 3.726235780797583*^9, 
   3.726235832043491*^9, {3.726238016487649*^9, 3.7262380187802134`*^9}, 
   3.7262389093474073`*^9},ExpressionUUID->"c7c1955d-d3e2-487d-9329-\
255000ee863a"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"25700", " ", "fcp\[Prime]"}], "-", 
   FractionBox[
    RowBox[{"157", " ", "fnr\[Prime]", " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{"t", "+", "ynp"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"257", "+", 
       RowBox[{"100", " ", "ynr"}]}], ")"}]}], 
    RowBox[{"p", " ", 
     RowBox[{"(", 
      RowBox[{"t", "+", "ynr"}], ")"}]}]]}], 
  RowBox[{"25700", " ", 
   RowBox[{"(", 
    RowBox[{"fcp\[Prime]", "+", 
     RowBox[{"fnp\[Prime]", " ", "ynp"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.7262389868327637`*^9},ExpressionUUID->"92e2466d-72af-44c3-b3e7-\
ae2af900c02b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "rhizobia", " ", "growth", " ", "when", " ", "trade", " ", "is", " ", 
    "ultimately", " ", "rhizobia", " ", "limited"}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"gRrlim", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"gr", "/.", "colim\[Prime]"}], "/.", "xrlim"}], "/.", 
     RowBox[{"acr", "\[Rule]", "0"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.473513780817618*^9, 3.473513798896906*^9}, 
   3.473515581742841*^9, {3.473684844513262*^9, 3.473684846496848*^9}, {
   3.5354594282173758`*^9, 3.535459473878806*^9}, 3.535460472588667*^9, 
   3.7262356314908113`*^9, 3.726235708731234*^9, 3.726235833276546*^9, 
   3.726236347658544*^9, {3.726238025197447*^9, 3.7262380412847147`*^9}, 
   3.726238910377297*^9},ExpressionUUID->"8123b366-24ce-4373-9771-\
4aff2b971f3a"],

Cell[BoxData[
 FractionBox[
  RowBox[{"157", " ", "fnr\[Prime]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "257"}], "+", 
     RowBox[{"100", " ", "t"}]}], ")"}], " ", "ynr"}], 
  RowBox[{"25700", " ", 
   RowBox[{"(", 
    RowBox[{"t", "+", "ynr"}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.726238987587739*^9},ExpressionUUID->"c7ae85b5-dad2-4097-ad0f-\
2793063cfe38"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
   "plant", " ", "growth", " ", "when", " ", "trade", " ", "is", " ", 
    "ultimately", " ", "rhizobia", " ", "limited"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"gPrlim", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"gp", "/.", "colim\[Prime]"}], "/.", "xrlim"}], "/.", 
     RowBox[{"acr", "\[Rule]", "0"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.47351391801978*^9, 3.473513921116947*^9}, {
   3.473515584843975*^9, 3.473515590400662*^9}, {3.4736848500258293`*^9, 
   3.4736848531994047`*^9}, {3.473684945867898*^9, 3.473684947587668*^9}, {
   3.535459803623374*^9, 3.5354598222052917`*^9}, 3.535460475180623*^9, {
   3.726235654774866*^9, 3.726235661361618*^9}, 3.7262357121950073`*^9, 
   3.726235786260503*^9, 3.7262358343012037`*^9, {3.726238045100312*^9, 
   3.72623805257902*^9}, 
   3.7262389115043592`*^9},ExpressionUUID->"c6c7b6c5-c4da-41b8-a370-\
c1a616352bf4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"ynp", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"25700", " ", "fcp\[Prime]", " ", "fnp\[Prime]", " ", "p", " ", 
       RowBox[{"(", 
        RowBox[{"t", "+", "ynr"}], ")"}]}], "+", 
      RowBox[{"157", " ", "fcp\[Prime]", " ", "fnr\[Prime]", " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{"257", "+", 
         RowBox[{"100", " ", "ynr"}]}], ")"}]}], "-", 
      RowBox[{
      "157", " ", "fnp\[Prime]", " ", "fnr\[Prime]", " ", "r", " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"257", "+", 
         RowBox[{"100", " ", "ynr"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"25700", " ", "p", " ", 
    RowBox[{"(", 
     RowBox[{"fcp\[Prime]", "+", 
      RowBox[{"fnp\[Prime]", " ", "ynp"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t", "+", "ynr"}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.7262389883252497`*^9},ExpressionUUID->"c323213f-028f-4e09-833c-\
aeb879380a98"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Predicting the C-for-N exchange ratio (T)", "Subsection",
 CellChangeTimes->{{3.4735092888156233`*^9, 3.473509290421665*^9}, {
   3.473684327756703*^9, 3.4736843284989853`*^9}, {3.535459899032177*^9, 
   3.535459900791875*^9}, 
   3.726235798281809*^9},ExpressionUUID->"5e23a6ea-8671-4ea6-b553-\
dc927d628af4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"symmetric", " ", "Nash", " ", "product"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPi]plim", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"gPplim", "-", "gpnox"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{"gRplim", "-", "grnox"}], ")"}]}]}], ";", 
    RowBox[{"\[CapitalPi]rlim", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"gPrlim", "-", "gpnox"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{"gRrlim", "-", "grnox"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "asymmetric", " ", "Nash", " ", "Product", " ", "when", " ", "beta"}], 
      " ", "=", " ", "0.8"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalPi]plim", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gPplim", "-", "gpnox"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"80", "/", "100"}], ")"}]}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gRplim", "-", "grnox"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"20", "/", "100"}], ")"}]}]}]}], ";", 
     RowBox[{"\[CapitalPi]rlim", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gPrlim", "-", "gpnox"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"80", "/", "100"}], ")"}]}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gRrlim", "-", "grnox"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"20", "/", "100"}], ")"}]}]}]}], ";"}], 
    "\[IndentingNewLine]", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.473685153612833*^9, 3.4736852152576647`*^9}, {
  3.535459930919855*^9, 3.535459963118726*^9}, {3.7262360519035397`*^9, 
  3.7262360682081337`*^9}, {3.726238073006425*^9, 3.726238088196721*^9}, {
  3.7262389231695213`*^9, 
  3.726238924043888*^9}},ExpressionUUID->"a1b37466-0b03-4b81-826c-\
7fa95627dd90"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "predicted", " ", "plant", " ", "T", " ", "using", " ", "the", " ", 
    "above", " ", "Nash", " ", "product", " ", "when", " ", "trade", " ", 
    "is", " ", "plant", " ", "limited"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"0", "\[Equal]", 
     RowBox[{"D", "[", 
      RowBox[{"\[CapitalPi]plim", ",", " ", "t"}], "]"}]}], ",", "t"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.471911912529415*^9, 3.471911928102169*^9}, {
  3.473162608644631*^9, 3.473162609326153*^9}, {3.4735074700065517`*^9, 
  3.4735074732548103`*^9}, {3.473685242660656*^9, 3.473685296542068*^9}, {
  3.473687320360085*^9, 3.473687323037332*^9}, {3.5354602333816357`*^9, 
  3.535460233693103*^9}, {3.535460270180546*^9, 3.535460288794878*^9}, {
  3.535460480660475*^9, 3.535460482235993*^9}, {3.535648441365377*^9, 
  3.535648441504724*^9}, {3.726236071818969*^9, 3.7262362205507097`*^9}, {
  3.7262381018295603`*^9, 3.726238116899763*^9}, {3.726238921853072*^9, 
  3.726238931985899*^9}, {3.7262389682270184`*^9, 
  3.7262389750146227`*^9}},ExpressionUUID->"c334edc7-a8bc-4a39-b7d4-\
11fcdcbd7876"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"t", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"51400", " ", "fcp\[Prime]", " ", "fcr\[Prime]"}], "+", 
       RowBox[{"80698", " ", "fcp\[Prime]", " ", "fnr\[Prime]"}], "+", 
       RowBox[{"25700", " ", "fcr\[Prime]", " ", "fnp\[Prime]", " ", "ynp"}], 
       "+", 
       RowBox[{"15700", " ", "fcp\[Prime]", " ", "fnr\[Prime]", " ", "ynp"}], 
       "+", 
       RowBox[{
       "40349", " ", "fnp\[Prime]", " ", "fnr\[Prime]", " ", "ynp"}]}], ")"}],
      "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"25700", " ", "fcr\[Prime]", " ", "fnp\[Prime]"}], "+", 
       RowBox[{"15700", " ", "fcp\[Prime]", " ", "fnr\[Prime]"}], "+", 
       RowBox[{"40349", " ", "fnp\[Prime]", " ", "fnr\[Prime]"}], "+", 
       RowBox[{
       "31400", " ", "fnp\[Prime]", " ", "fnr\[Prime]", " ", "ynp"}]}], 
      ")"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.726238989945866*^9},ExpressionUUID->"caa831ce-db61-4a6e-8509-\
c3bb92ac3c29"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "predicted", " ", "plant", " ", "T", " ", "using", " ", "the", " ", 
    "above", " ", "Nash", " ", "product", " ", "when", " ", "trade", " ", 
    "is", " ", "rhizobia", " ", "limited"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"0", "\[Equal]", 
     RowBox[{"D", "[", 
      RowBox[{"\[CapitalPi]rlim", ",", " ", "t"}], "]"}]}], ",", "t"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4736854186201687`*^9, 3.4736854186681633`*^9}, {
  3.5354602990429773`*^9, 3.535460314594679*^9}, {3.5356484451051273`*^9, 
  3.5356484452655573`*^9}, {3.726236198484214*^9, 3.726236218204652*^9}, {
  3.7262381426785307`*^9, 
  3.726238142816256*^9}},ExpressionUUID->"c3167263-1267-4d0b-b97f-\
fde930cc2a67"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"t", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"51400", " ", "fcp\[Prime]", " ", "fcr\[Prime]"}], "+", 
       RowBox[{"80698", " ", "fcp\[Prime]", " ", "fnr\[Prime]"}], "+", 
       RowBox[{"25700", " ", "fcr\[Prime]", " ", "fnp\[Prime]", " ", "ynr"}], 
       "+", 
       RowBox[{"15700", " ", "fcp\[Prime]", " ", "fnr\[Prime]", " ", "ynr"}], 
       "+", 
       RowBox[{
       "40349", " ", "fnp\[Prime]", " ", "fnr\[Prime]", " ", "ynr"}]}], ")"}],
      "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"25700", " ", "fcr\[Prime]", " ", "fnp\[Prime]"}], "+", 
       RowBox[{"15700", " ", "fcp\[Prime]", " ", "fnr\[Prime]"}], "+", 
       RowBox[{"40349", " ", "fnp\[Prime]", " ", "fnr\[Prime]"}], "+", 
       RowBox[{
       "31400", " ", "fnp\[Prime]", " ", "fnr\[Prime]", " ", "ynr"}]}], 
      ")"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.726238991289239*^9},ExpressionUUID->"f9c7fad0-0d97-470b-a9f1-\
9c5f80efa3d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "predicted", " ", "plant", " ", "T", " ", "using", " ", "the", " ", 
     "above", " ", "Nash", " ", "product", " ", "when", " ", "trade", " ", 
     "is", " ", "co"}], "-", "limited"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"\[CapitalPi]plim", "\[Equal]", "\[CapitalPi]rlim"}], ",", " ", 
    "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4736854186201687`*^9, 3.4736854186681633`*^9}, {
  3.473685480468218*^9, 3.473685497237423*^9}, {3.535460343162849*^9, 
  3.535460373060049*^9}, {3.726236209477233*^9, 3.726236215677309*^9}, {
  3.726238146159937*^9, 
  3.726238146471507*^9}},ExpressionUUID->"b32b6f46-37d1-4a93-a4fa-\
d5a825803e07"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", 
     FractionBox["fcp\[Prime]", "fnp\[Prime]"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", 
     FractionBox[
      RowBox[{"257", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"100", " ", "fcr\[Prime]"}], "+", 
         RowBox[{"157", " ", "fnr\[Prime]"}]}], ")"}]}], 
      RowBox[{"15700", " ", "fnr\[Prime]"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "40349"}], " ", "fnr\[Prime]", " ", "r", " ", "ynp"}], 
       "-", 
       RowBox[{"25700", " ", "fcp\[Prime]", " ", "p", " ", "ynr"}], "-", 
       RowBox[{
       "15700", " ", "fnr\[Prime]", " ", "r", " ", "ynp", " ", "ynr"}]}], 
      RowBox[{
       RowBox[{"25700", " ", "fcp\[Prime]", " ", "p"}], "+", 
       RowBox[{"40349", " ", "fnr\[Prime]", " ", "r"}], "+", 
       RowBox[{"15700", " ", "fnr\[Prime]", " ", "r", " ", "ynr"}]}]]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"40349", " ", "fnr\[Prime]", " ", "r", " ", "ynp"}], "-", 
       RowBox[{"25700", " ", "fcp\[Prime]", " ", "p", " ", "ynr"}], "+", 
       RowBox[{
       "15700", " ", "fnr\[Prime]", " ", "r", " ", "ynp", " ", "ynr"}]}], 
      RowBox[{
       RowBox[{"25700", " ", "fcp\[Prime]", " ", "p"}], "-", 
       RowBox[{"40349", " ", "fnr\[Prime]", " ", "r"}], "-", 
       RowBox[{"15700", " ", "fnr\[Prime]", " ", "r", " ", "ynr"}]}]]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726239000217204*^9},ExpressionUUID->"7567083c-5091-452a-bd16-\
9fb4c7258d6b"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{824, 982},
WindowMargins->{{848, Automatic}, {Automatic, 30}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"11.2 for Linux x86 (64-bit) (September 10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 221, 4, 68, "Section",ExpressionUUID->"da3e0881-e02c-430b-9752-d189594494ef"],
Cell[CellGroupData[{
Cell[826, 30, 161, 3, 55, "Subsection",ExpressionUUID->"f4c5663f-07f4-409c-bcfb-5319dacb70d3"],
Cell[990, 35, 3051, 82, 400, "Input",ExpressionUUID->"f5fe3749-a289-4b50-8065-cae120b360d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4078, 122, 255, 4, 55, "Subsection",ExpressionUUID->"0e0a2b7a-e589-4239-b9bd-5b5d129bc701"],
Cell[4336, 128, 2386, 62, 239, "Input",ExpressionUUID->"41c4a4cd-3237-4e2e-8ec8-433317143cd7"],
Cell[CellGroupData[{
Cell[6747, 194, 246, 4, 45, "Subsubsection",ExpressionUUID->"d32c7c3e-4511-4e12-afaf-c0839907b820"],
Cell[6996, 200, 1327, 31, 101, "Input",ExpressionUUID->"6b289a2b-42fe-4cb9-9c91-9ad798f3d6cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8360, 236, 321, 5, 45, "Subsubsection",ExpressionUUID->"102f513b-df39-4e7c-bea5-60658c909ffd"],
Cell[8684, 243, 1397, 31, 101, "Input",ExpressionUUID->"3746d68d-723e-4af4-a01f-80f165ac91f9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10130, 280, 265, 4, 55, "Subsection",ExpressionUUID->"72186bf5-3410-44d5-bbae-87990a869cff"],
Cell[10398, 286, 5515, 155, 699, "Input",ExpressionUUID->"a7104deb-09b8-4b27-9d9c-77a33722e7a1"],
Cell[CellGroupData[{
Cell[15938, 445, 299, 4, 45, "Subsubsection",ExpressionUUID->"38b300d4-9182-4d9c-9dad-0dc40b822f5d"],
Cell[CellGroupData[{
Cell[16262, 453, 792, 18, 55, "Input",ExpressionUUID->"7783c95d-8772-4879-9c0a-102e9169f339"],
Cell[17057, 473, 818, 25, 56, "Output",ExpressionUUID->"efd25634-edcd-4382-9be8-eb68ce70a02e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17912, 503, 1025, 22, 55, "Input",ExpressionUUID->"8d439f03-7e9f-4114-8f12-d65b00e0966a"],
Cell[18940, 527, 210, 6, 56, "Output",ExpressionUUID->"b09120fa-a506-4df3-a464-e9a997e103ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19187, 538, 999, 21, 55, "Input",ExpressionUUID->"dc2be358-cd41-4460-88f7-d8846c294c5f"],
Cell[20189, 561, 1016, 30, 56, "Output",ExpressionUUID->"46499038-827a-4040-855c-26aab38c79e1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21254, 597, 308, 4, 45, "Subsubsection",ExpressionUUID->"83890d21-f09f-4b17-9233-181a21c6aea2"],
Cell[CellGroupData[{
Cell[21587, 605, 982, 19, 55, "Input",ExpressionUUID->"c7c1955d-d3e2-487d-9329-255000ee863a"],
Cell[22572, 626, 648, 20, 68, "Output",ExpressionUUID->"92e2466d-72af-44c3-b3e7-ae2af900c02b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23257, 651, 878, 19, 55, "Input",ExpressionUUID->"8123b366-24ce-4373-9771-4aff2b971f3a"],
Cell[24138, 672, 385, 12, 56, "Output",ExpressionUUID->"c7ae85b5-dad2-4097-ad0f-2793063cfe38"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24560, 689, 981, 21, 55, "Input",ExpressionUUID->"c6c7b6c5-c4da-41b8-a370-c1a616352bf4"],
Cell[25544, 712, 989, 27, 59, "Output",ExpressionUUID->"c323213f-028f-4e09-833c-aeb879380a98"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26594, 746, 316, 5, 55, "Subsection",ExpressionUUID->"5e23a6ea-8671-4ea6-b553-dc927d628af4"],
Cell[26913, 753, 2041, 57, 216, "Input",ExpressionUUID->"a1b37466-0b03-4b81-826c-7fa95627dd90"],
Cell[CellGroupData[{
Cell[28979, 814, 1208, 23, 78, "Input",ExpressionUUID->"c334edc7-a8bc-4a39-b7d4-11fcdcbd7876"],
Cell[30190, 839, 1037, 26, 82, "Output",ExpressionUUID->"caa831ce-db61-4a6e-8509-c3bb92ac3c29"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31264, 870, 806, 19, 55, "Input",ExpressionUUID->"c3167263-1267-4d0b-b97f-fde930cc2a67"],
Cell[32073, 891, 1037, 26, 82, "Output",ExpressionUUID->"f9c7fad0-0d97-470b-a9f1-9c5f80efa3d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33147, 922, 765, 17, 55, "Input",ExpressionUUID->"b32b6f46-37d1-4a93-a4fa-d5a825803e07"],
Cell[33915, 941, 1692, 45, 146, "Output",ExpressionUUID->"7567083c-5091-452a-bd16-9fb4c7258d6b"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

